/* 
 This file is used to control the UI parts of the widget. There is no Eve API specific
 code in this file. See ecm.js for the core of the Eve API handling code.
 */

//
// Function: load()
// Called by HTML body element's onload event when the widget is ready to start
//
function load()
{
    dashcode.setupParts();
	
	version.innerText = "ECM " + G_VERSION;
	
	loadPreferences();

	// always check for updates on start
	if (true)
	{
		checkForUpdates();
	}
	else
	{
		refreshDataFromApi();
	}
	
	setTimeout("refreshDataFromApiHourly();", 3600000);
	nextRefreshValue.innerText = new Date((new Date()).getTime() + 3600000);

}

//
// Function: remove()
// Called when the widget has been removed from the Dashboard
//
function remove()
{
	G_TIMER_RUNNING = false;
	clearTimeout(G_SKILL_TIMER);
	clearTimeout(G_HOURLY_TIMER);
	
	savePreference("userId", null);
    savePreference("apiKey", null);
	savePreference("charName", null);
}

//
// Function: hide()
// Called when the widget has been hidden
//
function hide()
{
    // Stop any timers to prevent CPU usage
}

//
// Function: show()
// Called when the widget has been shown
//
function show()
{
    // Restart any timers that were stopped on hide
}

//
// Function: sync()
// Called when the widget has been synchronized with .Mac
//
function sync()
{
    savePreferences();
}

//
// Function: showBack(event)
// Called when the info button is clicked to show the back of the widget
//
// event: onClick event from the info button
//
function showBack(event)
{
	G_BACK_SHOWN = true;
	
    loadPreferences();
	
	errorText.innerText = "";
    
    var front = document.getElementById("front");
    var back = document.getElementById("back");

    if (window.widget) {
        widget.prepareForTransition("ToBack");
    }

    front.style.display = "none";
    back.style.display = "block";

    if (window.widget) {
        setTimeout('widget.performTransition();', 1);
    }
}

//
// Function: showFront(event)
// Called when the done button is clicked from the back of the widget
//
// event: onClick event from the done button
//
function showFront(event)
{
    savePreferences();
    
    var front = document.getElementById("front");
    var back = document.getElementById("back");

    if (window.widget) {
        widget.prepareForTransition("ToFront");
    }

    front.style.display="block";
    back.style.display="none";

    if (window.widget) {
        setTimeout('widget.performTransition();', 0);
    }
	
	G_BACK_SHOWN = false;
}

if (window.widget) {
    widget.onremove = remove;
    widget.onhide = hide;
    widget.onshow = show;
    widget.onsync = sync;
}


function unload(event)
{
	G_TIMER_RUNNING = false;
	clearTimeout(G_SKILL_TIMER);
	clearTimeout(G_HOURLY_TIMER);
}

function loadPreferences() {
    loadPreferenceIntoInput("userId", userIdValue);
    loadPreferenceIntoInput("apiKey", apiKeyValue);
	loadPreferenceIntoText("charName", selectedCharacterValue);
}

function savePreferences() {
    savePreferenceFromInput("userId", userIdValue);
    savePreferenceFromInput("apiKey", apiKeyValue);
	//savePreferenceFromInput("checkUpdates", checkUpdates);
}

function getCharacterListClicked(event)
{
	savePreferences();
    getCharactersFromApi();
}

function characterSelectedFromList(event)
{
	stopSkillTimer();
	
	var popupValue = document.getElementById("charactersList");
	var charId = popupValue.object.getValue();
	var charName = popupValue.innerText;
	
	saveSetting("charId", charId);
	saveSetting("charName", charName);
	loadPreferenceIntoText("charName", selectedCharacterValue);
}

function refreshDataClicked(event)
{
    refreshDataFromApi();
}


function showCharacterSheetView(event)
{
	transitionView('stackLayout', 'characterSheet');
}

function showSkillQueue(event)
{
	transitionView('stackLayout', 'queue');
}

function transitionView(stackLayout, view)
{
	newTransition = new Transition(Transition.CUBE_TYPE, 1, Transition.EASE_TIMING);
	document.getElementById(stackLayout).object.setCurrentViewWithTransition(view, newTransition, false);
}

function showBaptistProfile(event)
{
    widget.openURL("https://gate.eveonline.com/Profile/TheBaptist");
}


function showApiPage(event)
{
	widget.openURL("http://www.eveonline.com/api/");
}

function okErrorButtonClicked(event)
{
	transitionView('stackLayout', 'characterSheet');
    G_ERROR_SHOWN = false;
}
